@@ -1,4 +1,4 @@
-`newgraphwindow` <-
+newgraphwindow <-
 function() {
 # This function aims to create graphics windows on different OS's where possible
 graphoutcome <- try(windows(),silent=TRUE)
